from nagiosplugin.check import Check as Check
from nagiosplugin.context import Context as Context
from nagiosplugin.context import ScalarContext as ScalarContext
from nagiosplugin.cookie import Cookie as Cookie
from nagiosplugin.error import CheckError as CheckError
from nagiosplugin.error import Timeout as Timeout
from nagiosplugin.logtail import LogTail as LogTail
from nagiosplugin.metric import Metric as Metric
from nagiosplugin.multiarg import MultiArg as MultiArg
from nagiosplugin.performance import Performance as Performance
from nagiosplugin.range import Range as Range
from nagiosplugin.resource import Resource as Resource
from nagiosplugin.result import Result as Result
from nagiosplugin.result import Results as Results
from nagiosplugin.runtime import Runtime as Runtime
from nagiosplugin.runtime import guarded as guarded
from nagiosplugin.state import (
    Critical as Critical,
)
from nagiosplugin.state import (
    Ok as Ok,
)
from nagiosplugin.state import (
    Unknown as Unknown,
)
from nagiosplugin.state import (
    Warn as Warn,
)
from nagiosplugin.summary import Summary as Summary
from nagiosplugin.version import __VERSION__

__version__: str = ...



from types import TracebackType
from typing import Generator, Optional, Type

from nagiosplugin.cookie import Cookie

class LogTail:
    def __init__(self, path: str, cookie: Cookie) -> None: ...
    def __enter__(self) -> Generator[bytes, None, None]: ...
    def __exit__(
        self,
        exc_type: Optional[Type[BaseException]],
        exc_val: Optional[BaseException],
        exc_tb: Optional[TracebackType],
    ) -> Optional[bool]: ...



from typing import Iterator

class MultiArg:
    def __init__(
        self, args: list[str] | str, fill: str = ..., splitchar: str = ...
    ) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[str]: ...
    def __getitem__(self, key: int) -> str: ...



from dataclasses import dataclass
from typing import Generator, Literal

from nagiosplugin.context import Context
from nagiosplugin.metric import Metric
from nagiosplugin.resource import Resource
from nagiosplugin.state import ServiceState

@dataclass
class Result:
    state: ServiceState
    hint: str | None = None
    metric: Metric | None = None
    def __new__(
        cls, state: ServiceState, hint: str | None = ..., metric: Metric | None = ...
    ) -> Result: ...
    def __str__(self) -> str: ...
    @property
    def resource(self) -> Resource | None: ...
    @property
    def context(self) -> Context | None: ...

class ScalarResult(Result):
    def __new__(
        cls, state: ServiceState, hint: str | None = ..., metric: Metric | None = ...
    ) -> ScalarResult: ...

class Results:
    results: list[Result]
    by_state: dict[Literal[0, 1, 2, 3], Result]
    by_name: dict[str, Result]

    def __init__(self, *results: Result) -> None: ...
    def add(self, *results: Result) -> Results: ...
    def __iter__(self) -> Generator[Result, None, None]: ...
    def __len__(self) -> int: ...
    def __getitem__(self, item: int | str) -> Result: ...
    def __contains__(self, name: str) -> bool: ...
    @property
    def most_significant_state(self) -> ServiceState: ...
    @property
    def most_significant(self) -> list[Result]: ...
    @property
    def first_significant(self) -> Result: ...



from collections import UserDict
from types import TracebackType
from typing import Any, Optional, Type

class Cookie(UserDict[str, Any]):
    def __init__(self, statefile: str = ...) -> None: ...
    def __enter__(self) -> Cookie: ...
    def __exit__(
        self,
        exc_type: Optional[Type[BaseException]],
        exc_val: Optional[BaseException],
        exc_tb: Optional[TracebackType],
    ) -> Optional[bool]: ...
    def open(self) -> Cookie: ...
    def close(self) -> None: ...
    def commit(self) -> None: ...



from dataclasses import dataclass
from typing import Any

from nagiosplugin.context import Context
from nagiosplugin.performance import Performance
from nagiosplugin.resource import Resource
from nagiosplugin.result import Result
from typing_extensions import TypedDict, Unpack

class MetricKwargs(TypedDict, total=False):
    name: str
    value: Any
    uom: str
    min: float
    max: float
    context: str
    contextobj: Context
    resource: Resource

@dataclass
class Metric:
    name: str
    value: Any
    uom: str | None = None
    min: float | None = None
    max: float | None = None
    context: str | None = None
    contextobj: Context | None = None
    resource: Resource | None = None

    def replace(self, **attr: Unpack[MetricKwargs]) -> Metric: ...
    @property
    def description(self) -> str: ...
    @property
    def valueunit(self) -> str: ...
    def evaluate(self) -> Result: ...
    def performance(self) -> Performance: ...
